@@ -24,17 +24,20 @@ import (
 	"context"
 	"encoding/json"
 	"errors"
+	"io"
 	"net/http"
 	"net/url"
 	"os"
 	"os/exec"
+	"path/filepath"
 	"runtime"
+	"strconv"
 	"strings"
 	"syscall"
 	"time"
 
-	"github.com/minio/madmin-go/v2/cgroup"
-	"github.com/minio/madmin-go/v2/kernel"
+	"github.com/minio/madmin-go/v3/cgroup"
+	"github.com/minio/madmin-go/v3/kernel"
 	"github.com/prometheus/procfs"
 	"github.com/shirou/gopsutil/v3/cpu"
 	"github.com/shirou/gopsutil/v3/disk"
@@ -140,8 +143,25 @@ type CPU struct {
 type CPUs struct {
 	NodeCommon
 
-	CPUs          []CPU `json:"cpus,omitempty"`
-	IsFreqGovPerf *bool `json:"is_freq_gov_perf,omitempty"`
+	CPUs         []CPU          `json:"cpus,omitempty"`
+	CPUFreqStats []CPUFreqStats `json:"freq_stats,omitempty"`
+}
+
+// CPUFreqStats CPU frequency stats
+type CPUFreqStats struct {
+	Name                     string
+	CpuinfoCurrentFrequency  *uint64
+	CpuinfoMinimumFrequency  *uint64
+	CpuinfoMaximumFrequency  *uint64
+	CpuinfoTransitionLatency *uint64
+	ScalingCurrentFrequency  *uint64
+	ScalingMinimumFrequency  *uint64
+	ScalingMaximumFrequency  *uint64
+	AvailableGovernors       string
+	Driver                   string
+	Governor                 string
+	RelatedCpus              string
+	SetSpeed                 string
 }
 
 // GetCPUs returns system's all CPU information.
@@ -184,16 +204,16 @@ func GetCPUs(ctx context.Context, addr string) CPUs {
 		cpus = append(cpus, cpu)
 	}
 
-	var igp *bool
-	isGovPerf, err := isFreqGovPerf()
-	if err == nil {
-		igp = &isGovPerf
+	var errMsg string
+	freqStats, err := getCPUFreqStats()
+	if err != nil {
+		errMsg = err.Error()
 	}
 
 	return CPUs{
-		NodeCommon:    NodeCommon{Addr: addr},
-		CPUs:          cpus,
-		IsFreqGovPerf: igp,
+		NodeCommon:   NodeCommon{Addr: addr, Error: errMsg},
+		CPUs:         cpus,
+		CPUFreqStats: freqStats,
 	}
 }
 
@@ -286,6 +306,18 @@ type TimeInfo struct {
 	TimeZone          string    `json:"time_zone"`
 }
 
+// XFSErrorConfigs - stores the error configs of all XFS devices on the server
+type XFSErrorConfigs struct {
+	Configs []XFSErrorConfig `json:"configs,omitempty"`
+	Error   string           `json:"error,omitempty"`
+}
+
+// XFSErrorConfig - stores XFS error configuration info for max_retries
+type XFSErrorConfig struct {
+	ConfigFile string `json:"config_file"`
+	MaxRetries int    `json:"max_retries"`
+}
+
 // GetOSInfo returns linux only operating system's information.
 func GetOSInfo(ctx context.Context, addr string) OSInfo {
 	if runtime.GOOS != "linux" {
@@ -330,7 +362,7 @@ func GetOSInfo(ctx context.Context, addr string) OSInfo {
 
 // GetSysConfig returns config values from the system
 // (only those affecting minio performance)
-func GetSysConfig(ctx context.Context, addr string) SysConfig {
+func GetSysConfig(_ context.Context, addr string) SysConfig {
 	sc := SysConfig{
 		NodeCommon: NodeCommon{Addr: addr},
 		Config:     map[string]interface{}{},
@@ -352,11 +384,59 @@ func GetSysConfig(ctx context.Context, addr string) SysConfig {
 		TimeZone:    zone,
 	}
 
+	xfsErrorConfigs := getXFSErrorMaxRetries()
+	if len(xfsErrorConfigs.Configs) > 0 || len(xfsErrorConfigs.Error) > 0 {
+		sc.Config["xfs-error-config"] = xfsErrorConfigs
+	}
+
 	return sc
 }
 
+func readIntFromFile(filePath string) (num int, err error) {
+	var file *os.File
+	file, err = os.Open(filePath)
+	if err != nil {
+		return
+	}
+	defer file.Close()
+
+	var data []byte
+	data, err = io.ReadAll(file)
+	if err != nil {
+		return
+	}
+
+	return strconv.Atoi(strings.TrimSpace(string(data)))
+}
+
+func getXFSErrorMaxRetries() XFSErrorConfigs {
+	xfsErrCfgPattern := "/sys/fs/xfs/*/error/metadata/*/max_retries"
+	configFiles, err := filepath.Glob(xfsErrCfgPattern)
+	if err != nil {
+		return XFSErrorConfigs{Error: err.Error()}
+	}
+
+	configs := []XFSErrorConfig{}
+	var errMsg string
+	for _, configFile := range configFiles {
+		maxRetries, err := readIntFromFile(configFile)
+		if err != nil {
+			errMsg = err.Error()
+			break
+		}
+		configs = append(configs, XFSErrorConfig{
+			ConfigFile: configFile,
+			MaxRetries: maxRetries,
+		})
+	}
+	return XFSErrorConfigs{
+		Configs: configs,
+		Error:   errMsg,
+	}
+}
+
 // GetSysServices returns info of sys services that affect minio
-func GetSysServices(ctx context.Context, addr string) SysServices {
+func GetSysServices(_ context.Context, addr string) SysServices {
 	ss := SysServices{
 		NodeCommon: NodeCommon{Addr: addr},
 		Services:   []SysService{},
@@ -397,7 +477,7 @@ func getSELinuxInfo() (SysService, error) {
 }
 
 // GetSysErrors returns issues in system setup/config
-func GetSysErrors(ctx context.Context, addr string) SysErrors {
+func GetSysErrors(_ context.Context, addr string) SysErrors {
 	se := SysErrors{NodeCommon: NodeCommon{Addr: addr}}
 	if runtime.GOOS != "linux" {
 		return se
