@@ -149,9 +149,10 @@ type BucketUsageInfo struct {
 	ReplicationPendingCount uint64 `json:"objectsPendingReplicationCount"`
 	ReplicationFailedCount  uint64 `json:"objectsFailedReplicationCount"`
 
-	VersionsCount        uint64            `json:"versionsCount"`
-	ObjectsCount         uint64            `json:"objectsCount"`
-	ObjectSizesHistogram map[string]uint64 `json:"objectsSizesHistogram"`
+	VersionsCount           uint64            `json:"versionsCount"`
+	ObjectsCount            uint64            `json:"objectsCount"`
+	ObjectSizesHistogram    map[string]uint64 `json:"objectsSizesHistogram"`
+	ObjectVersionsHistogram map[string]uint64 `json:"objectsVersionsHistogram"`
 }
 
 // DataUsageInfo represents data usage stats of the underlying Object API
@@ -222,6 +223,17 @@ func (adm *AdminClient) DataUsageInfo(ctx context.Context) (DataUsageInfo, error
 	return dataUsageInfo, nil
 }
 
+// ErasureSetInfo provides information per erasure set
+type ErasureSetInfo struct {
+	ID            int    `json:"id"`
+	RawUsage      uint64 `json:"rawUsage"`
+	RawCapacity   uint64 `json:"rawCapacity"`
+	Usage         uint64 `json:"usage"`
+	ObjectsCount  uint64 `json:"objectsCount"`
+	VersionsCount uint64 `json:"versionsCount"`
+	HealDisks     int    `json:"healDisks"`
+}
+
 // InfoMessage container to hold server admin related information.
 type InfoMessage struct {
 	Mode         string             `json:"mode,omitempty"`
@@ -234,47 +246,31 @@ type InfoMessage struct {
 	Versions     Versions           `json:"versions,omitempty"`
 	Usage        Usage              `json:"usage,omitempty"`
 	Services     Services           `json:"services,omitempty"`
-	Backend      interface{}        `json:"backend,omitempty"`
+	Backend      ErasureBackend     `json:"backend,omitempty"`
 	Servers      []ServerProperties `json:"servers,omitempty"`
+
+	Pools map[int]map[int]ErasureSetInfo `json:"pools,omitempty"`
 }
 
 func (info InfoMessage) BackendType() BackendType {
 	// MinIO server type default
-	backendType := Unknown
-
-	// Set the type of MinIO server ("FS", "Erasure", "Unknown")
-	switch v := info.Backend.(type) {
-	case FSBackend:
-		backendType = FS
-	case ErasureBackend:
-		backendType = Erasure
-	case map[string]interface{}:
-		vt, ok := v["backendType"]
-		if ok {
-			backendTypeS, _ := vt.(string)
-			switch backendTypeS {
-			case "Erasure":
-				backendType = Erasure
-			}
-		}
+	switch info.Backend.Type {
+	case "Erasure":
+		return Erasure
+	case "FS":
+		return FS
+	default:
+		return Unknown
 	}
-	return backendType
 }
 
 func (info InfoMessage) StandardParity() int {
 	switch info.BackendType() {
 	case Erasure:
-		switch v := info.Backend.(type) {
-		case ErasureBackend:
-			return v.StandardSCParity
-		case map[string]interface{}:
-			scParity, ok := v["standardSCParity"].(float64)
-			if ok {
-				return int(scParity)
-			}
-		}
+		return info.Backend.StandardSCParity
+	default:
+		return -1
 	}
-	return -1
 }
 
 // Services contains different services information
@@ -368,6 +364,10 @@ type ErasureBackend struct {
 	StandardSCParity int `json:"standardSCParity"`
 	// Parity disks for currently configured Reduced Redundancy storage class.
 	RRSCParity int `json:"rrSCParity"`
+
+	// Per pool information
+	TotalSets    []int `json:"totalSets"`
+	DrivesPerSet []int `json:"totalDrivesPerSet"`
 }
 
 // ServerProperties holds server information
@@ -422,6 +422,7 @@ type Disk struct {
 	Utilization     float64      `json:"utilization,omitempty"`
 	Metrics         *DiskMetrics `json:"metrics,omitempty"`
 	HealInfo        *HealingDisk `json:"heal_info,omitempty"`
+	UsedInodes      uint64       `json:"used_inodes"`
 	FreeInodes      uint64       `json:"free_inodes,omitempty"`
 
 	// Indexes, will be -1 until assigned a set.
