@@ -464,7 +464,8 @@ type JobMetric struct {
 	Failed   bool `json:"failed"`
 
 	// Specific job type data:
-	Replicate *ReplicateInfo `json:"replicate,omitempty"`
+	Replicate *ReplicateInfo   `json:"replicate,omitempty"`
+	KeyRotate *KeyRotationInfo `json:"rotation,omitempty"`
 }
 
 type ReplicateInfo struct {
@@ -479,6 +480,16 @@ type ReplicateInfo struct {
 	BytesFailed      int64 `json:"bytesFailed"`
 }
 
+type KeyRotationInfo struct {
+	// Last bucket/object key rotated
+	Bucket string `json:"lastBucket"`
+	Object string `json:"lastObject"`
+
+	// Verbose information
+	Objects       int64 `json:"objects"`
+	ObjectsFailed int64 `json:"objectsFailed"`
+}
+
 // Merge other into 'o'.
 func (o *BatchJobMetrics) Merge(other *BatchJobMetrics) {
 	if other == nil || len(other.Jobs) == 0 {
